@@ -41,7 +41,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '3.3';
+our $VERSION = '3.6';
 
 # use the same constant as in the Perl-SDK
 use constant DEBUG => $ENV{MONITIS_DEBUG} || 0;
@@ -205,21 +205,33 @@ sub get_id_of_monitor($$$) {
 # handles a raw command (add_monitor, update_data)
 sub handle_raw_command($$) {
 	my ($self, $raw) = @_;
-	print "$raw\n";
-	my ($command, $monitor_name, @raw_parameters) = split /\s+/, $raw;
+	print "Raw command is: '$raw'\n";
+	my (@raw_parameters) = split /\s+/, $raw;
+	my $command = pop @raw_parameters;
 
 	# a quick debug message
-	carp "Handling raw command: '$command', monitor_name: '$monitor_name'" if DEBUG;
+	carp "Handling raw command: '$command'" if DEBUG;
 
 	for ($command) {
 		/add_monitor/ and do {
-			my ($monitor_tag, $result_params) = @raw_parameters;
+			my $monitor_name = pop @raw_parameters;
+			my $monitor_tag = pop @raw_parameters;
+			my $result_params = pop @raw_parameters;
 			$self->add_monitor_raw($monitor_name, $monitor_tag, $result_params);
 		};
 		/update_data/ and do {
-			my ($monitor_tag, $result_params) = @raw_parameters;
+			my $monitor_name = pop @raw_parameters;
+			my $monitor_tag = pop @raw_parameters;
+			my $result_params = pop @raw_parameters;
 			$self->update_data_for_monitor_raw("", $monitor_name, $monitor_tag, time, $result_params);
 		};
+		/list_monitors/ and do {
+			$self->list_monitors_raw();
+		};
+		/delete_monitor/ and do {
+			my $monitor_id = pop @raw_parameters;
+			$self->delete_monitor_raw($monitor_id);
+		};
 	}
 }
 
@@ -289,6 +301,30 @@ sub add_monitor_raw($$$$@) {
 		$monitor_name, $monitor_tag, $result_params, @add_monitor_optional_params);
 }
 
+# list monitors
+sub list_monitors_raw($) {
+	my ($self) = @_;
+	my @monitors = $self->{monitis_connection}->list_monitors();
+	my $i = 0;
+
+	printf("ID   |Name           |Tag                      |Type           |\n");
+	printf("-----|---------------|-------------------------|---------------|\n");
+	while (defined($monitors[0][$i])) {
+		my ($monitor_name) = $monitors[0][$i]->{name};
+		my ($monitor_type) = $monitors[0][$i]->{type};
+		my ($monitor_tag) = $monitors[0][$i]->{tag};
+		my ($monitor_id) = $monitors[0][$i]->{id};
+		printf("%-5s|%-15s|%-25s|%-15s|\n", $monitor_id, $monitor_name, $monitor_tag, $monitor_type);
+		$i++;
+	}
+}
+
+# delete a monitor
+sub delete_monitor_raw($$) {
+	my ($self, $monitor_id) = @_;
+	my @monitors = $self->{monitis_connection}->delete_monitor($monitor_id);
+}
+
 # add all monitors for all agents
 sub add_agents($) {
 	my ($self) = @_;
@@ -638,8 +674,10 @@ This Perl module helps you manage Custom Monitors on Monitis (www.monitis.com).
 For full proper documentation please refer to:
 https://github.com/monitisexchange/Monitis-Linux-Scripts/blob/master/M3v3/README.md
 
-M3 Perl module is incomplete on its own, you should also use the monitis-m3
-package which packages an init.d service. Find it here:
+M3 Perl module comes with an init.d service. If you're using a RPM or DEB
+package then you're good to do, however the CPAN installation will not take
+care of this...
+Find it here:
 https://github.com/monitisexchange/Monitis-Linux-Scripts/tree/master/M3v3
 
 =head2 EXPORT
