@@ -1,6 +1,7 @@
 package MonitisMonitorManager::Execution::SNMP;
 use strict;
 use MonitisMonitorManager::M3PluginCommon;
+use Carp;
 require Net::SNMP;
 
 sub new {
@@ -43,14 +44,14 @@ sub execute {
 	);
 
 	if (!defined $session) {
-		MonitisMonitorManager::M3PluginCommon::log_message("err", "SNMP Error: " . $error);
+		carp "SNMP Error: ", $error;
 		return "";
 	}
 
 	my $result = $session->get_request(-varbindlist => [ $oid ],);
 
 	if (!defined $result) {
-		MonitisMonitorManager::M3PluginCommon::log_message("err", "SNMP Error: " . $session->error());
+		carp "SNMP Error: ", $session->error();
 		$session->close();
 		return "";
 	}
