@@ -1,7 +1,7 @@
 package MonitisMonitorManager::Parsing::JSON;
-use MonitisMonitorManager::M3PluginCommon;
 use strict;
-use JSON;
+use Carp;
+require JSON;
 
 sub new {
 	my ($class, $name) = @_;
@@ -32,7 +32,7 @@ sub match_strings_in_object {
 		if (defined(eval "\$presentation->$metric_string"))
 		{
 			my $data = eval "\$presentation->$metric_string";
-			MonitisMonitorManager::M3PluginCommon::log_message("debug", "Matched '$metric_string'=>'$data'");
+			carp "Matched '$metric_string'=>'$data'";
 			${$results}{$metric_name} = $data;
 		}
 	}
